home | help
libprelude-config(1)	     General Commands Manual	    libprelude-config(1)

NAME
     libprelude-config - helper script for building with libprelude

SYNOPSIS
     libprelude-config [options]

DESCRIPTION
     libprelude-config	is  a simple shell script used to determine the compiler
     and linker flags that should be used to compile and link programs that  use
     the libprelude library.

OPTIONS
     --prefix=dir   If	specified,  use  dir  instead of the installation prefix
		    that the library was built with, when computing  the  output
		    for  the  --cflags	and --libs options.  This option must be
		    specified before any --libs or --cflags options. This option
		    is also used for the exec prefix if the --exec-prefix option
		    is not specified.
     --exec-prefix=dir
		    If specified, use dir instead of the exec installation  pre-
		    fix that the library was built with, when computing the out-
		    put for the --cflags and --libs options. This option must be
		    specified before any --libs or --cflags options.
     --config-prefix
		    Print the directory prefix where libprelude configuration is
		    installed on the standard output.
     --version	    Print  the currently installed version of the library on the
		    standard output.
     --c++	    If specified, indicate that the linkage will be done with  a
		    C++ library
     --libs	    Print  the	linker flags that are necessary to link with the
		    specified library.
     --ldflags	    Print the LDflags that are necessary to  compile  a  program
		    using the specified library.
     --cflags	    Print  the	compiler  flags  that are necessary to compile a
		    program using the specified library.
     --pthread-cflags
		    Print the pthread compiler flags that are necessary to  com-
		    pile a program using the specified library.
AUTHOR
     This man page has been written by CS GROUP - France

				   2 May 2016		    libprelude-config(1)

home | help